[![PyPI version](https://badge.fury.io/py/omegaconf.svg)](https://badge.fury.io/py/omegaconf)
[![Build Status](https://travis-ci.com/omry/omegaconf.svg?branch=master)](https://travis-ci.com/omry/omegaconf)
[![Documentation Status](https://readthedocs.org/projects/omegaconf/badge/?version=latest)](https://omegaconf.readthedocs.io/en/latest/?badge=latest)
[![downloads](https://img.shields.io/pypi/dm/omegaconf.svg)](https://pypistats.org/packages/omegaconf)
[![Coverage Status](https://coveralls.io/repos/github/omry/omegaconf/badge.svg)](https://coveralls.io/github/omry/omegaconf)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/omry/omegaconf/master?filepath=docs%2Fnotebook%2FTutorial.ipynb)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/omegaconf.svg)
# OmegaConf

OmegaConf is a YAML based hierarchical configuration system, with support for merging configurations from multiple sources (multiple config files, CLI argument)
providing a consistent API regardless of how the configuration was created.

Run the live tutorial : [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/omry/omegaconf/master?filepath=docs%2Fnotebook%2FTutorial.ipynb)

[Read the docs](https://omegaconf.readthedocs.io/en/latest/?badge=latest).
